@@ -26,6 +26,7 @@ where
 {
     #[inline]
     fn extend<T: IntoIterator<Item = (&'a K, &'a V)>>(&mut self, iter: T) {
-        self.extend(iter.into_iter().map(|(&key, &value)| (key, value)));
+        self.base
+            .extend(iter.into_iter().map(|(&key, &value)| (key, value)));
     }
 }
